{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "bc077a0d-3cac-4f63-8b00-fa6d878fe2a7",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "hide-input",
     "hide-cell",
     "remove-input"
    ]
   },
   "outputs": [],
   "source": [
    "from vega import Vega\n",
    "import altair as alt\n",
    "import numpy as np\n",
    "\n",
    "import pandas as pd\n",
    "institutions_df = pd.read_csv(\"institution-totals.csv\")\n",
    "\n",
    "library_institutions_df = institutions_df.query('sector == \"library\"')"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "da9d64f3-2654-48e4-b31d-f42f260f535c",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "# Library Institutions Overview"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "eb26e498-3320-4d0d-b76a-083d47f66391",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-input",
     "full-width"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-68d637adc79b4d8584f2fbc33f6e3d19.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-68d637adc79b4d8584f2fbc33f6e3d19.vega-embed details,\n",
       "  #altair-viz-68d637adc79b4d8584f2fbc33f6e3d19.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-68d637adc79b4d8584f2fbc33f6e3d19\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-68d637adc79b4d8584f2fbc33f6e3d19\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-68d637adc79b4d8584f2fbc33f6e3d19\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.17.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.17.0\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"numberFormat\": \".2s\"}, \"vconcat\": [{\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"British Library\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"British Library\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 33810000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#c6dbef\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 33810000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#c6dbef\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-c699b8c2b21ecba010dfe3e7bde445c3\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-1eccdc9f23e4c898d583dc48503f1dbc\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"British Library\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Chetham's Library\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Chetham's Library\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 121041\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#c6dbef\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 121041\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#c6dbef\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-7d6a0c9fe645c4b43c807be0780a39ba\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-1eccdc9f23e4c898d583dc48503f1dbc\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Chetham's Library\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Glasgow Woman's Library\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Glasgow Woman's Library\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-0e3349a3c0c293b6b05eda085bba5deb\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-1eccdc9f23e4c898d583dc48503f1dbc\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Glasgow Woman's Library\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Lambeth Palace Library\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Lambeth Palace Library\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 186200\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#c6dbef\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 186200\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#c6dbef\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-e267cd564620e8be2a98c9d85ddc9026\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-1eccdc9f23e4c898d583dc48503f1dbc\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Lambeth Palace Library\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}, {\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"National Library of Scotland\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"National Library of Scotland\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 37000000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-3d5398a27b9ecca9ee675dadc5c0b1dc\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-1eccdc9f23e4c898d583dc48503f1dbc\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"National Library of Scotland\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"National Library of Wales\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"National Library of Wales\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 7540000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#c6dbef\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 7540000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#c6dbef\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-35658a61e75fa0680f6a74a992acbaea\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-1eccdc9f23e4c898d583dc48503f1dbc\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"National Library of Wales\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}], \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.17.0.json\", \"datasets\": {\"data-c699b8c2b21ecba010dfe3e7bde445c3\": [{\"institution\": \"British Library\", \"values\": 33810000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"British Library\", \"values\": 0, \"calculated\": 33810000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"British Library\", \"values\": 33810000, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"British Library\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"British Library\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"British Library\", \"values\": 0, \"calculated\": 33810000, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"British Library\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-1eccdc9f23e4c898d583dc48503f1dbc\": [{\"institution\": \"British Library\", \"sector\": \"library\", \"artefacts\": 33810000, \"objects\": 0, \"library_items\": 33810000, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Chetham's Library\", \"sector\": \"library\", \"artefacts\": 121041, \"objects\": 0, \"library_items\": 121041, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Glasgow Woman's Library\", \"sector\": \"library\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Lambeth Palace Library\", \"sector\": \"library\", \"artefacts\": 186200, \"objects\": 0, \"library_items\": 186200, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"National Library of Wales\", \"sector\": \"library\", \"artefacts\": 7540000, \"objects\": 0, \"library_items\": 7540000, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"National Library of Scotland\", \"sector\": \"library\", \"artefacts\": 37000000, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}], \"data-7d6a0c9fe645c4b43c807be0780a39ba\": [{\"institution\": \"Chetham's Library\", \"values\": 121041, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Chetham's Library\", \"values\": 0, \"calculated\": 121041, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Chetham's Library\", \"values\": 121041, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Chetham's Library\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Chetham's Library\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Chetham's Library\", \"values\": 0, \"calculated\": 121041, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Chetham's Library\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-0e3349a3c0c293b6b05eda085bba5deb\": [{\"institution\": \"Glasgow Woman's Library\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Glasgow Woman's Library\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Glasgow Woman's Library\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Glasgow Woman's Library\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Glasgow Woman's Library\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Glasgow Woman's Library\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Glasgow Woman's Library\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-e267cd564620e8be2a98c9d85ddc9026\": [{\"institution\": \"Lambeth Palace Library\", \"values\": 186200, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Lambeth Palace Library\", \"values\": 0, \"calculated\": 186200, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Lambeth Palace Library\", \"values\": 186200, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Lambeth Palace Library\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Lambeth Palace Library\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Lambeth Palace Library\", \"values\": 0, \"calculated\": 186200, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Lambeth Palace Library\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-3d5398a27b9ecca9ee675dadc5c0b1dc\": [{\"institution\": \"National Library of Scotland\", \"values\": 37000000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"National Library of Scotland\", \"values\": 0, \"calculated\": 37000000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"National Library of Scotland\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"National Library of Scotland\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"National Library of Scotland\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"National Library of Scotland\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"National Library of Scotland\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-35658a61e75fa0680f6a74a992acbaea\": [{\"institution\": \"National Library of Wales\", \"values\": 7540000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"National Library of Wales\", \"values\": 0, \"calculated\": 7540000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"National Library of Wales\", \"values\": 7540000, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"National Library of Wales\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"National Library of Wales\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"National Library of Wales\", \"values\": 0, \"calculated\": 7540000, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"National Library of Wales\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.VConcatChart(...)"
      ]
     },
     "execution_count": 3,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "row_count = 0\n",
    "row_graphs = []\n",
    "grid_graphs = []\n",
    "\n",
    "for i, institution in library_institutions_df.sort_values(by=[\"institution\"]).iterrows():\n",
    "    institution_name = institution[\"institution\"]\n",
    "    title = alt.TitleParams(institution_name, anchor='middle')\n",
    "    row_df = pd.DataFrame(\n",
    "       {\"institution\": institution_name,\n",
    "        \"values\": [\n",
    "             institution[\"artefacts\"],\n",
    "            institution[\"objects\"], institution[\"library_items\"], institution[\"archive_items\"],\n",
    "            institution[\"object_records\"], institution[\"library_records\"], institution[\"archive_records\"]],\n",
    "       \"calculated\": [\n",
    "            min(institution[\"object_records\"] + institution[\"library_records\"] + institution[\"archive_records\"], institution[\"artefacts\"]),\n",
    "            institution[\"artefacts\"],\n",
    "            min(institution[\"object_records\"], institution[\"objects\"]), institution[\"objects\"],\n",
    "            min(institution[\"library_records\"], institution[\"library_items\"]), institution[\"library_items\"],\n",
    "         institution[\"archive_items\"] ],\n",
    "            \"labels\": [\"Artefacts\", \n",
    "                                  \"Museum Objects\", \n",
    "                                  \"Library Items\",\n",
    "                                  \"Archive Items/Collections\", \n",
    "                                  \"Museum Records\", \n",
    "                                  \"Library Records\", \"Archive Records\"],\n",
    "            \"labels_calculated\": [ \"Artefacts Catalogued\", \"Artefacts\", \"Objects Catalogued\", \"Objects\",\n",
    "                                  \"Library Items Catalogued\", \"Library Items\",\n",
    "                                   \"Archive Items\"]\n",
    "            })\n",
    "\n",
    "    # Ring gives summary of cataloguing progress\n",
    "    #ring = alt.Chart(row_df).mark_arc(innerRadius=90, outerRadius=100).encode(\n",
    "    #  color=\"labels_calculated:N\",\n",
    "    #  theta=\"calculated\",\n",
    "    #)\n",
    "\n",
    "    if institution[\"artefacts\"] > 0:\n",
    "     catalogued_records =  institution[\"object_records\"] + institution[\"library_records\"] + institution[\"archive_records\"]\n",
    "     if catalogued_records > 0:\n",
    "         catalogued_proportion = min(catalogued_records / institution[\"artefacts\"], 1) * 2.09\n",
    "         ring1_complete = alt.Chart().mark_arc(\n",
    "             tooltip=f'Catalogued Artefacts: {catalogued_records}',\n",
    "             innerRadius=90, outerRadius=100,theta=0,color=\"gold\", \n",
    "                                theta2=catalogued_proportion - 0.02)\n",
    "         if catalogued_proportion < 2.09:\n",
    "           ring1_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=catalogued_proportion,color=\"#9ecae1\", \n",
    "                                                  theta2=2.07,\n",
    "                                                  tooltip=f'Total Artefacts: {institution[\"artefacts\"]}')\n",
    "         else:\n",
    "           ring1_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=0,color=\"grey\", theta2=0)\n",
    "     else:\n",
    "        ring1_complete = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=0,color=\"#9ecae1\", theta2=0)\n",
    "        ring1_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=0,theta2=2.07,color=\"#9ecae1\",\n",
    "                                               tooltip=f'Total Artefacts: {institution[\"artefacts\"]}')\n",
    "    else:\n",
    "      ring1_complete = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=0,color=\"grey\", theta2=0)\n",
    "      ring1_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=0,theta2=2.07,color=\"grey\",\n",
    "                                             tooltip=f'Total Artefacts: {institution[\"artefacts\"]}')\n",
    "\n",
    "\n",
    "    if institution[\"objects\"] > 0:\n",
    "     catalogued_records =  institution[\"object_records\"] \n",
    "     if catalogued_records > 0:\n",
    "         catalogued_proportion = min(catalogued_records / institution[\"objects\"], 1) * 2.09\n",
    "         ring2_complete = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=2.09,color=\"gold\",\n",
    "                                               theta2=2.09 + catalogued_proportion - 0.02, \n",
    "                                                            tooltip=f'Catalogued Objects: {catalogued_records}')\n",
    "         if catalogued_proportion < 2.09:\n",
    "           ring2_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=2.09+ catalogued_proportion,color=\"#fd8d3c\", \n",
    "                                                  theta2=4.16, tooltip=f'Total Objects: {institution[\"objects\"]}')\n",
    "     else:\n",
    "        ring2_complete = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=2.09,color=\"#fd8d3c\", theta2=2.09)\n",
    "        ring2_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=2.09,theta2=4.16,color=\"#fd8d3c\",\n",
    "                                               tooltip=f'Total Objects: {institution[\"objects\"]}')\n",
    "    else:\n",
    "      ring2_complete = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=2.09,color=\"grey\", theta2=2.09)\n",
    "      ring2_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=2.09,theta2=4.16,color=\"grey\", \n",
    "                                             tooltip=f'Total Objects: {institution[\"objects\"]}')  \n",
    "        \n",
    "#    ring2 = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=2.09,theta2=4.16,color=\"gray\")\n",
    "\n",
    "    if institution[\"library_items\"] > 0:\n",
    "     catalogued_records = institution[\"library_records\"] \n",
    "     if catalogued_records > 0:\n",
    "         catalogued_proportion = min(catalogued_records / institution[\"library_items\"], 1) * 2.09\n",
    "         ring3_complete = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,\n",
    "                                               theta=4.18,color=\"gold\", \n",
    "                                               tooltip=f'Catalogued Library Items: {catalogued_records}',\n",
    "                                               theta2=4.18 + catalogued_proportion - 0.02)\n",
    "         if catalogued_proportion < 2.09:\n",
    "           ring3_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=4.18+catalogued_proportion,color=\"#c6dbef\", \n",
    "                                                  theta2=6.27, tooltip=f'Total Library Items: {institution[\"library_items\"]}')\n",
    "     else:\n",
    "        ring3_complete = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=4.18,color=\"#c6dbef\", theta2=4.18)\n",
    "        ring3_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=4.18,theta2=6.27,\n",
    "                                               color=\"#c6dbef\", tooltip=f'Total Library Items: {institution[\"library_items\"]}')\n",
    "    else:\n",
    "      ring3_complete = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=4.18,color=\"grey\", theta2=4.18)\n",
    "      ring3_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=4.18,theta2=6.27,color=\"grey\",\n",
    "                                             tooltip=f'Total Library Items: {institution[\"library_items\"]}') \n",
    "        \n",
    "#    ring3 = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=4.18,theta2=6.27,color=\"orange\")\n",
    "\n",
    "    # Petal graph ? gives summary of size of instution collections\n",
    "    base1 = alt.Chart(row_df, width=160, title=title).encode(\n",
    "      alt.Theta(\"values:Q\").stack(True),\n",
    "      alt.Radius(\"values\").scale(type=\"sqrt\", zero=True, rangeMin=20),\n",
    "      tooltip='labels:N',\n",
    "      color=alt.Color(\"labels:N\", sort=\"ascending\").legend(orient=\"top\", titleOrient=\"left\").scale(scheme=\"category20c\"),\n",
    "    ).properties(\n",
    "      width=200,\n",
    "      height=200\n",
    "    )\n",
    "\n",
    "#    text_complete = alt.Chart().mark_text().encode(\n",
    "#        text=f\"{institution['artefacts']}:Q\")\n",
    "#        text=alt.Text(institution[\"artefacts\"]), color=\"gold\").properties(width=100)\n",
    "    \n",
    "    petal_marks = base1.mark_arc(innerRadius=45, outerRadius=60, cornerRadius=5, \n",
    "                                 stroke=\"#fff\")\n",
    "    \n",
    "#    petal_text = base1.mark_text(radiusOffset=58).encode(text=\"values:Q\")\n",
    "#    alt.FieldGTPredicate(\"values\", 0), alt.Text('values:Q'), alt.value(''))\n",
    "\n",
    "    petal_text = base1.mark_text(radiusOffset=58).encode(\n",
    "        text=alt.condition(alt.FieldGTPredicate(\"values\", 0), alt.Text('values:Q'), alt.value('')))\n",
    "\n",
    "    # Bar at bottom indicates proportion of national collection this institution has\n",
    "    bar = alt.Chart(library_institutions_df, height=20, width=200).mark_bar().encode(\n",
    "      alt.X(\"artefacts\").title(\"Proportion of National Collection\"),\n",
    "      tooltip='artefacts',\n",
    "      color=alt.condition(\n",
    "        alt.FieldOneOfPredicate('institution', [institution_name]),\n",
    "        alt.value('gold'),     \n",
    "        alt.value('white')     \n",
    "      )\n",
    "    )\n",
    "    \n",
    "    institution_graph = alt.vconcat((petal_marks + petal_text + ring1_complete + \n",
    "                                     ring1_remaining + ring2_complete + ring2_remaining +\n",
    "                                     ring3_remaining + ring3_complete), bar).resolve_scale(theta='independent')\n",
    "    if row_count < 3:\n",
    "        row_graphs.append(institution_graph)\n",
    "        row_count += 1\n",
    "    else:   \n",
    "        row_graphs.append(institution_graph)\n",
    "        grid_graphs.append(\n",
    "            alt.hconcat(*row_graphs, spacing=40).resolve_scale(theta='shared'))\n",
    "        row_count = 0\n",
    "        row_graphs = []\n",
    "\n",
    "if row_count > 0:\n",
    "    grid_graphs.append(\n",
    "            alt.hconcat(*row_graphs, spacing=40).resolve_scale(theta='shared'))\n",
    "\n",
    "alt.vconcat(*grid_graphs).configure(numberFormat='.2s')\n",
    "#alt.hconcat(*row_graphs, spacing=40).configure(numberFormat='.2s').resolve_scale(theta='shared')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "488bd315-b12b-4503-b226-a864ba934206",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.9.18"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
